@@ -1,23 +1,21 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
-import velbus
+from velbus.message import Message
+from velbus.command_registry import register_command
 
 COMMAND_CODE = 0xd9
 
 
-class BusErrorStatusRequestMessage(velbus.Message):
+class BusErrorStatusRequestMessage(Message):
     """
     send by:
     received by: VMB6IN, VMB4RYLD
     """
 
-    def __init__(self):
-        velbus.Message.__init__(self)
-
     def populate(self, priority, address, rtr, data):
         """
-        @return None
+        :return: None
         """
         assert isinstance(data, bytes)
         self.needs_low_priority(priority)
@@ -27,9 +25,9 @@ class BusErrorStatusRequestMessage(velbus.Message):
 
     def data_to_binary(self):
         """
-        @return: bytes
+        :return: bytes
         """
         return bytes([COMMAND_CODE])
 
 
-velbus.register_command(COMMAND_CODE, BusErrorStatusRequestMessage)
+register_command(COMMAND_CODE, BusErrorStatusRequestMessage)
