@@ -90,10 +90,17 @@ class ChannelNamePart1Message3(ChannelNamePart1Message):
  
 register_command(COMMAND_CODE, ChannelNamePart1Message)
 register_command(COMMAND_CODE, ChannelNamePart1Message2, 'VMBGP1')
+register_command(COMMAND_CODE, ChannelNamePart1Message2, 'VMBEL1')
+register_command(COMMAND_CODE, ChannelNamePart1Message2, 'VMBGP1-2')
 register_command(COMMAND_CODE, ChannelNamePart1Message2, 'VMBGP2')
+register_command(COMMAND_CODE, ChannelNamePart1Message2, 'VMBEL2')
+register_command(COMMAND_CODE, ChannelNamePart1Message2, 'VMBGP2-2')
 register_command(COMMAND_CODE, ChannelNamePart1Message2, 'VMBGP4')
+register_command(COMMAND_CODE, ChannelNamePart1Message2, 'VMBEL4')
+register_command(COMMAND_CODE, ChannelNamePart1Message2, 'VMBGP4-2')
 register_command(COMMAND_CODE, ChannelNamePart1Message2, 'VMBGPO')
 register_command(COMMAND_CODE, ChannelNamePart1Message2, 'VMBGPOD')
+register_command(COMMAND_CODE, ChannelNamePart1Message2, 'VMBELO')
 register_command(COMMAND_CODE, ChannelNamePart1Message2, 'VMBGP4PIR')
 register_command(COMMAND_CODE, ChannelNamePart1Message3, 'VMB1BL')
 register_command(COMMAND_CODE, ChannelNamePart1Message3, 'VMB2BL')
