@@ -90,10 +90,17 @@ class ChannelNamePart2Message3(ChannelNamePart2Message):
 
 register_command(COMMAND_CODE, ChannelNamePart2Message)
 register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBGP1')
+register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBEL1')
+register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBGP1-2')
 register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBGP2')
+register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBEL2')
+register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBGP2-2')
 register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBGP4')
+register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBEL4')
+register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBGP4-2')
 register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBGPO')
 register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBGPOD')
+register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBELO')
 register_command(COMMAND_CODE, ChannelNamePart2Message2, 'VMBGP4PIR')
 register_command(COMMAND_CODE, ChannelNamePart2Message3, 'VMB1BL')
 register_command(COMMAND_CODE, ChannelNamePart2Message3, 'VMB2BL')
