@@ -1,12 +1,13 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
-import velbus
+from velbus.message import Message
+from velbus.command_registry import register_command
 
 COMMAND_CODE = 0x0c
 
 
-class ReceiveReadyMessage(velbus.Message):
+class ReceiveReadyMessage(Message):
     """
     send by:
     received by: VMB1USB
@@ -14,7 +15,7 @@ class ReceiveReadyMessage(velbus.Message):
 
     def populate(self, priority, address, rtr, data):
         """
-        @return: None
+        :return: None
         """
         # self.needs_low_priority(priority)
         self.needs_no_rtr(rtr)
@@ -23,9 +24,9 @@ class ReceiveReadyMessage(velbus.Message):
 
     def data_to_binary(self):
         """
-        @return: bytes
+        :return: bytes
         """
         return bytes([COMMAND_CODE])
 
 
-velbus.register_command(COMMAND_CODE, ReceiveReadyMessage)
+register_command(COMMAND_CODE, ReceiveReadyMessage)
