@@ -2,20 +2,20 @@
 :author: Thomas Delaet <thomas@delaet.org>
 """
 import json
-import logging
-import velbus
+from velbus.message import Message
+from velbus.command_registry import register_command
 
 COMMAND_CODE = 0xde
 
 
-class SwitchToSafeMessage(velbus.Message):
+class SwitchToSafeMessage(Message):
     """
     send by:
     received by: VMB4RYLD
     """
 
     def __init__(self, address=None, sleep=0):
-        velbus.Message.__init__(self)
+        Message.__init__(self)
         self.sleep = sleep
         self.set_defaults(address)
 
@@ -44,4 +44,5 @@ class SwitchToSafeMessage(velbus.Message):
             0x00
         ])
 
-velbus.register_command(COMMAND_CODE, SwitchToSafeMessage)
+
+register_command(COMMAND_CODE, SwitchToSafeMessage)
